/*--------------------------------------------------------------------------
L420B.H
Header file for the Dallas DS89C420 - GP-IB/RS232 interface
 2003 Ales Vobornik
--------------------------------------------------------------------------*/

/*  BYTE Registers  */
sfr P0      = 0x80;     // Port 0
sfr SP      = 0x81;     // Stack Pointer
sfr DPL     = 0x82;     // Data Pointer Low 0
sfr DPH     = 0x83;     // Data Pointer High 0
sfr PCON    = 0x87;     // Power Control
sfr TCON    = 0x88;     // Timer Control
sfr TMOD    = 0x89;     // Timer Mode Control
sfr TL0     = 0x8A;     // Timer 0 Low
sfr TL1     = 0x8B;     // Timer 1 Low
sfr TH0     = 0x8C;     // Timer 0 High
sfr TH1     = 0x8D;     // Timer 1 High

sfr P1      = 0x90;     // Port 1
sfr SCON    = 0x98;     // Serial Port Control 0
sfr SBUF    = 0x99;     // Serial Port Buffer 0

sfr DAT     = 0xA0;     // Port 2
sfr IE      = 0xA8;     // Interrupt Enable

sfr P3      = 0xB0;     // Port 3
sfr IP      = 0xB8;     // Interrupt Priority

sfr PSW     = 0xD0;     // Program Status Word

sfr ACC     = 0xE0;     // Accumulator

sfr B       = 0xF0;     // B Register

/*  DS89C420 Extensions  */
sfr DPL1    = 0x84;     // Data Pointer Low 1
sfr DPH1    = 0x85;     // Data Pointer High 1
sfr DPS     = 0x86;     // Data Pointer Select
sfr CKCON   = 0x8E;     // Clock Control

sfr EXIF    = 0x91;     // External Interrupt Flag
sfr CKMOD   = 0x96;     // Timer and Serial Port Clock Mode
sfr ACON    = 0x9D;     // Address Control

sfr SADDR0  = 0xA9;     // Slave Address 0
sfr SADDR1  = 0xAA;     // Slave Address 1

sfr IP1     = 0xB1;     // Interrupt Priority 1
sfr SADEN0  = 0xB9;     // Slave Address Mask Enable 0
sfr SADEN1  = 0xBA;     // Slave Address Mask Enable 1

sfr SCON1   = 0xC0;     // Serial Port Control 1
sfr SBUF1   = 0xC1;     // Serial Port Buffer 1
sfr ROMSIZE = 0xC2;     // ROM Size Select
sfr BP2     = 0xC3;
sfr PMR     = 0xC4;     // Power Management
sfr STATUS  = 0xC5;     // Status
sfr TA      = 0xC7;     // Time Access
sfr T2CON   = 0xC8;     // Timer 2 Control
sfr T2MOD   = 0xC9;     // Timer 2 Mode
sfr RCAP2L  = 0xCA;     // Timer 2 Capture Low
sfr RCAP2H  = 0xCB;     // Timer 2 Capture High
sfr TL2     = 0xCC;     // Timer 2 Low
sfr TH2     = 0xCD;     // Timer 2 High

sfr FCNTL   = 0xD5;     // Flash Memory Control
sfr FDATA   = 0xD6;     // Flash Memory Data
sfr WDCON   = 0xD8;     // Watchdog Control

sfr EIE     = 0xE8;     // Extended Interrupt Enable

sfr EIP1    = 0xF1;     // Extended Interrupt Priority 1
sfr EIP     = 0xF8;     // Extended Interrupt Priority 0

/*  BIT Registers  */
/*  P0 (0x90) Bit Registers */
sbit L_REA = 0x80;      // Ready LED
sbit L_REC = 0x81;      // Receive LED
sbit L_TR  = 0x82;      // Transmit LED
sbit L_ERR = 0x83;      // Error LED
sbit S1    = 0x86;      // Switch 1
sbit S0    = 0x87;      // Switch 0

/*  PCON (0x87) Bit Values  */
#define IDL_    0x01    // Idle Mode Bit: 1=Active
#define STOP_   0x02    // Stop Mode Bit: 1=Active

#define GF0_    0x04    // General Purpose Flag 0
#define GF1_    0x08    // General Purpose Flag 1

#define OFDE_   0x10    // Oscillator Fail Detect Enable
#define OFDF_   0x20    // Oscillator Fail Detect Flag

#define SMOD0_  0x40    // Framing Error Detection Enable
#define SMOD_   0x80    // Double Baud Rate

/*  TCON (0x88) Bit Registers  */
sbit IT0  = 0x88;       // Interrupt 0 Type Control
sbit IE0  = 0x89;       // Interrupt 0 Edge Flag
sbit IT1  = 0x8A;       // Interrupt 1 Type Control
sbit IE1  = 0x8B;       // Interrupt 1 Edge Flag
sbit TR0  = 0x8C;       // Timer 0 Run Control
sbit TF0  = 0x8D;       // Timer 0 Overflow Flag
sbit TR1  = 0x8E;       // Timer 1 Run Control
sbit TF1  = 0x8F;       // Timer 1 Overflow Flag

/*  TMOD (0x89) Bit Values  */
#define T0_M0_   0x01   // Timer 0 Mode Bit 0
#define T0_M1_   0x02   // Timer 0 Mode Bit 1
#define T0_CT_   0x04   // Timer 0 Counter/Timer Select: 0=Counter, 1=Timer
#define T0_GATE_ 0x08   // Timer 0 Gate Control

#define T1_M0_   0x10   // Timer 1 Mode Bit 0
#define T1_M1_   0x20   // Timer 1 Mode Bit 1
#define T1_CT_   0x40   // Timer 1 Counter/Timer Select: 0=Counter, 1=Timer
#define T1_GATE_ 0x80   // Timer 1 Gate Control

#define T1_MASK_ 0xF0   // Timer 0 Mask
#define T0_MASK_ 0x0F   // Timer 1 Mask

/*  P1 (0x90) Bit Registers  */
sbit REM   = 0x90;      // REN GP-IB signal
sbit UNTALK= 0x91;      // UNTALK Internal signal
sbit READY = 0x92;      // READY Internal signal
sbit ADR   = 0x93;      // ADR Internal signal
sbit EOI   = 0x95;      // EOI GP-IB signal
sbit ATN   = 0x96;      // ATN GP-IB signal
sbit SRQ   = 0x97;      // SRQ GP-IB signal

/*  SCON (0x98) Bit Registers  */
sbit RI   = 0x98;       // Receive Interrupt Flag
sbit TI   = 0x99;       // Transmit Interrupt Flag
sbit RB8  = 0x9A;       // 9th data bit received
sbit TB8  = 0x9B;       // 9th data bit to be transmitted
sbit REN  = 0x9C;       // Receive Enable
sbit SM2  = 0x9D;       // Serial Port Mode Bit 2
sbit SM1  = 0x9E;       // Serial Port Mode Bit 1
sbit SM0  = 0x9F;       // Serial Port Mode Bit 0

/*  IE (0xA8) Bit Registers  */
sbit EINT = 0xA8;       // External Interrupt 0 Enable: 1=Enabled
sbit ET0  = 0xA9;       // Timer 0 Interrupt Enable: 1=Enabled
sbit EIFC = 0xAA;       // External Interrupt 1 Enable: 1=Enabled
sbit ET1  = 0xAB;       // Timer 1 Interrupt Enable: 1=Enabled
sbit ES   = 0xAC;       // UART 0 Interrupt Enable: 1=Enabled
sbit ET2  = 0xAD;       // Timer 2 Interrupt Enable: 1=Enabled
sbit ES1  = 0xAE;       // UART 1 Interrupt Enable: 1=Enabled
sbit EA   = 0xAF;       // Global Interrupt Enable: 0=Disable all interrupts

/*  P3 (0xB0) Bit Registers  */
sbit INT   = 0xB2;      // Interrupt GP-IB
sbit IFC   = 0xB3;      // Interrupt GP-IB IFC signal
sbit RSO   = 0xB6;      // RTS/DTR RS232 signal
sbit RSI   = 0xB7;      // CTS/DSR RS232 signal

/*  IP (0xB8) Bit Registers (Least Significant)  */
sbit PINT = 0xB8;       // External Interrupt 0 Priority
sbit PT0  = 0xB9;       // Timer 0 Interrupt Priority
sbit PIFC = 0xBA;       // External Interrupt 1 Priority
sbit PT1  = 0xBB;       // Timer 1 Interrupt Priority
sbit PS   = 0xBC;       // Serial Port 0 Interrupt Priority
sbit PT2  = 0xBD;       // Timer 2 Interrupt Priority
sbit PS1  = 0xBE;       // Serial Port 1 Interrupt Priority

/*  PSW (0xD0) Bit Registers  */
sbit P    = 0xD0;       // Parity Flag
sbit FL   = 0xD1;       // User Flag
sbit OV   = 0xD2;       // Overflow Flag
sbit RS0  = 0xD3;       // Register Bank Select Bit 0
sbit RS1  = 0xD4;       // Register Bank Select Bit 1
sbit F0   = 0xD5;       // User Flag 0
sbit AC   = 0xD6;       // Auxiliary Carry Flag
sbit CY   = 0xD7;       // Carry Flag

/*  DPS (0x86) Bit Values  */
#define SEL_     0x01   // Data Pointer Select
#define AID_     0x10   // Auto Increment/Decrement Enable
#define TSL_     0x20   // Toggle Select
#define ID0_     0x40   // Increment / Decrement Select for DPTR
#define ID1_     0x80   // Increment / Decrement Select for DPTR 1

/*  CKCON (0x8E) Bit Values  */
#define MD0_     0x01   // Stretch MOVX Select 0
#define MD1_     0x02   // Stretch MOVX Select 1
#define MD2_     0x04   // Stretch MOVX Select 2
 /* 000 = 2MC; 001 = 3MC*; 010 = 4MC; 011 = 5MC; */
 /* 100 = 9MC; 101 = 10MC; 110 = 11MC; 111 = 12MC */

#define T0M_     0x08   // Timer 0 Clock Select
#define T1M_     0x10   // Timer 1 Clock Select
#define T2M_     0x20   // Timer 2 Clock Select

#define WD0_     0x40   // Watchdog Timer Mode Select 0
#define WD1_     0x80   // Watchdog Timer Mode Select 1

/*  EXIF (0x91) Bit Values  */
#define BGS_     0x01   // Band-gap Select

#define RGSL_    0x02   // Ring Oscillator Select
#define RGMD_    0x04   // Ring Mode Status
#define CKRY_    0x08   // Clock Ready

#define IE2_     0x10   // External Interrupt 2 Flag
#define IE3_     0x20   // External Interrupt 3 Flag
#define IE4_     0x40   // External Interrupt 4 Flag
#define IE5_     0x80   // External Interrupt 5 Flag

/*  CKMOD (0x96) Bit Values  */
#define T0MH_    0x08   // Timer 0 Clock Mode High Speed Select
#define T1MH_    0x10   // Timer 1 Clock Mode High Speed Select
#define T2MH_    0x20   // Timer 2 Clock Mode High Speed Select

/*  ACON (0x9D) Bit Values  */
#define PAGES0_  0x20   // Page Mode Select 0
#define PAGES1_  0x40   // Page Mode Select 1
#define PAGEE_   0x80   // Page Mode Enable

/*  IP1 (0xB1) Bit Values (Most Significant)  */
#define MINT_    0x01   // External Interrupt 0 Priority
#define MPT0_    0x02   // Timer 0 Interrupt Priority
#define MIFC_    0x04   // External Interrupt 1 Priority
#define MPT1_    0x08   // Timer 1 Interrupt Priority
#define MPS_     0x10   // Serial Port 0 Interrupt Priority
#define MPT2_    0x20   // Timer 1 Interrupt Priority
#define MPS1_    0x40   // Serial Port 0 Interrupt Priority

/*  SCON1 (0xC0) Bit Registers  */
sbit RI1  = 0xC0;       // Receive Interrupt Flag
sbit TI1  = 0xC1;       // Transmit Interrupt Flag
sbit RB81 = 0xC2;       // 9th data bit received
sbit TB81 = 0xC3;       // 9th data bit to be transmitted
sbit REN1 = 0xC4;       // Receive Enable
sbit SM21 = 0xC5;       // Serial Port Mode Bit 2
sbit SM11 = 0xC6;       // Serial Port Mode Bit 1
sbit SM01 = 0xC7;       // Serial Port Mode Bit 0

/*  ROMSIZE (0xC2) Bit Values  */
#define RMS0_    0x01   // ROM Memory Size Select 0
#define RMS1_    0x02   // ROM Memory Size Select 1
#define RMS2_    0x04   // ROM Memory Size Select 2
#define PRAME_   0x08   // Program RAM Enable

/*  PMR (0xC4) Bit Values */
#define DME0_    0x01   // Data Memory Enable 0
#define DME1_    0x02   // Data Memory Enable 1
#define ALEON_   0x04   // ALE Enable
#define X4_      0x08   // Clock Multiplier Selection
#define CTM_     0x10   // Crystal Multiplier Enable
#define SWB_     0x20   // Switchback Enable
#define CD0_     0x40   // Clock Divide Control 0
#define CD1_     0x80   // Clock Divide Control 1

/*  STATUS (0xC5) Bit Values */
#define SPRA0_   0x01   // Serial Port 0 Receive Activity Monitor
#define SPTA0_   0x02   // Serial Port 0 Transmit Activity Monitor
#define SPRA1_   0x04   // Serial Port 1 Receive Activity Monitor
#define SPTA1_   0x08   // Serial Port 1 Transmit Activity Monitor

#define PIS0_    0x20   // Priority Interrupt Status 0
#define PIS1_    0x40   // Priority Interrupt Status 1
#define PIS2_    0x80   // Priority Interrupt Status 2

/*  T2CON (0xC8) Bit Registers  */
sbit CP_RL2= 0xC8;      // 0=Reload, 1=Capture select
sbit C_T2 = 0xC9;       // 0=Timer, 1=Counter
sbit TR2  = 0xCA;       // 0=Stop timer, 1=Start timer
sbit EXEN2= 0xCB;       // Timer 2 external enable
sbit TCLK = 0xCC;       // 0=Serial clock uses Timer 1 overflow, 1=Timer 2
sbit RCLK = 0xCD;       // 0=Serial clock uses Timer 1 overflow, 1=Timer 2
sbit EXF2 = 0xCE;       // Timer 2 external flag
sbit TF2  = 0xCF;       // Timer 2 overflow flag

/*  T2MOD (0xC9) Bit Values  */
#define DCEN_   0x01    // 1=Timer 2 can be configured as up/down counter
#define T2OE_   0x02    // Timer 2 output enable

/*  FCNTL (0xD5) Bit Values */
#define FC0_     0x01   // Flash Command 0
#define FC1_     0x02   // Flash Command 1
#define FC2_     0x04   // Flash Command 2
#define FC3_     0x08   // Flash Command 3

#define FERR_    0x40   // Flash Error
#define FBUSY_   0x80   // Flash Busy

/*  WDCON (0xD8) Bit Registers  */
sbit RWT  = 0xD8;       // Reset Watchdog Timer
sbit EWT  = 0xD9;       // Enable Watchdog Timer Reset
sbit WTRF = 0xDA;       // Watchdog Timer Reset Flag
sbit WDIF = 0xDB;       // Watchdog Interrupt Flag
sbit PFI  = 0xDC;       // Power fail Interrupt Flag
sbit EPFI = 0xDD;       // Enable Power fail Interrupt
sbit POR  = 0xDE;       // Power-on Reset Flag
sbit SMOD = 0xDF;       // Serial Modification

/*  EIE (0xE8) Bit Registers  */
sbit EX2  = 0xE8;       // External Interrupt 2 Enable
sbit EX3  = 0xE9;       // External Interrupt 3 Enable
sbit EX4  = 0xEA;       // External Interrupt 4 Enable
sbit EX5  = 0xEB;       // External Interrupt 5 Enable
sbit EWDI = 0xEC;       // Watchdog Interrupt Enable

/*  EIP1 (0xF1) Bit Values (Most Significant)  */
#define MPX2_    0x01   // External Interrupt 2 Priority
#define MPX3_    0x02   // External Interrupt 3 Priority
#define MPX4_    0x04   // External Interrupt 4 Priority
#define MPX5_    0x08   // External Interrupt 5 Priority
#define MPWDI_   0x10   // Watchdog Interrupt Priority

/*  EIP (0xF8) Bit Registers (Least Significant)  */
sbit POV  = 0xF8;       // External Interrupt 2 Priority
sbit PRED = 0xF9;       // External Interrupt 3 Priority
sbit PAD  = 0xFA;       // External Interrupt 4 Priority
sbit PMOD = 0xFB;       // External Interrupt 5 Priority
sbit PWDI = 0xFC;       // Watchdog Interrupt Priority

/*  Interrupt Vectors  */
#define VECTOR_INT   0  // 0x03 External Interrupt 0
#define VECTOR_TIMER 1  // 0x1B Timer 0
#define VECTOR_IFC   2  // 0x13 External Interrupt 1
#define TF1_VECTOR   3  // 0x0B Timer 1
#define VECTOR_S     4  // 0x23 Serial port 0
#define TF2_VECTOR   5  // 0x2B Timer 2
#define PFI_VECTOR   6  // 0x33 Power-fail Indicator
#define S1_VECTOR    7  // 0x3B Serial port 1
#define IE2_VECTOR   8  // 0x43 External Interrupt 2
#define IE3_VECTOR   9  // 0x4B External Interrupt 3
#define IE4_VECTOR  10  // 0x53 External Interrupt 4

